==> nativescript-vue-2.0.0-alpha.0.tgz: package/README.md <==
<p align="center">
    <a href="https://nativescript-vue.org">
        <img src="https://art.nativescript-vue.org/NativeScript-Vue.svg" width="270">
    </a>
</p>

<p align="center">
    <a href="https://github.com/prettier/prettier">
       <img src="https://img.shields.io/badge/styled_with-prettier-ff69b4.svg" alt="styled with prettier">
    </a>
    <a href="https://www.npmjs.com/package/nativescript-vue">
       <img src="https://img.shields.io/npm/v/nativescript-vue.svg" alt="npm">
    </a>
    <a href="https://github.com/nativescript-vue/nativescript-vue/blob/master/LICENSE">
       <img src="https://img.shields.io/github/license/nativescript-vue/nativescript-vue.svg" alt="license">
    </a>
    <a href="https://circleci.com/gh/nativescript-vue/nativescript-vue/tree/master">
       <img src="https://img.shields.io/circleci/project/github/nativescript-vue/nativescript-vue.svg" alt="CircleCI">
    </a>
    <a href="https://codecov.io/gh/nativescript-vue/nativescript-vue">
       <img src="https://img.shields.io/codecov/c/github/nativescript-vue/nativescript-vue.svg" alt="Codecov">
    </a>
</p>

<h2 align="center">Supporting NativeScript-Vue</h2>

NativeScript-Vue is an MIT-licensed open source project made possible by our sponsors:

<!--sponsors-->
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle">
        <a href="https://www.privateinternetaccess.com/" target="_blank">
          <img width="300px" src="https://art.nativescript-vue.org/sponsors/pia.png">
        </a>
      </td>
      <td align="center" valign="middle">
        <a href="https://kiwiirc.com/" target="_blank">
          <img height="90px" src="https://art.nativescript-vue.org/sponsors/kiwiirc.png">
        </a>
      </td>
    </tr><tr></tr>
  </tbody>
</table>
<!--/sponsors-->

and these awesome backers:

- Tiago Alves
- Kamen Bundev
- Jan Weller
- OpenLitterMap
- Aparajita Fishman
- Hajnalka Molnár Csikós
- Jen Looper
- Packy Tagliaferro
- Alexander Vakrilov
- Dave
- Todd Anglin
- Mohamed Hussain
- Gleb Zhelezin
- Robert M. Svendsen
- Andy Drexler
- ChiwalahSoftware
- Nayir Chami

If you'd like to join them, please consider [becoming a backer / sponsor on Patreon](https://www.patreon.com/rigor789).

A huge thank you for all of the backers / sponsors!

---

# NativeScript Vue Plugin

This plugin integrates [Vue](https://vuejs.org/) and [NativeScript](https://www.nativescript.org/), allowing you to build cross-platform iOS and Android apps using Vue.

## Contributing

If you feel like contributing to this project, that’s awesome! Start by reading [this repo’s `CONTRIBUTING.MD`](https://github.com/rigor789/nativescript-vue/blob/master/CONTRIBUTING.md) file for details on the required development setup, how to send pull requests, and how to run this repo’s sample app.

If you’d like to get involved with making Vue integration for NativeScript happen, join us in the #vue channel on the [NativeScript community Slack](http://tinyurl.com/nativescriptSlack). 

## License

NativeScript-Vue is licensed under the [MIT license](https://github.com/rigor789/nativescript-vue/blob/master/LICENSE)

==> nativescript-vue-2.5.0-alpha.0.tgz: package/README.md <==
<p align="center">
    <a href="https://nativescript-vue.org">
        <img src="https://art.nativescript-vue.org/NativeScript-Vue.svg" width="270">
    </a>
</p>

<p align="center">
    <a href="https://github.com/prettier/prettier">
       <img src="https://img.shields.io/badge/styled_with-prettier-ff69b4.svg" alt="styled with prettier">
    </a>
    <a href="https://www.npmjs.com/package/nativescript-vue">
       <img src="https://img.shields.io/npm/v/nativescript-vue.svg" alt="npm">
    </a>
    <a href="https://github.com/nativescript-vue/nativescript-vue/blob/master/LICENSE">
       <img src="https://img.shields.io/github/license/nativescript-vue/nativescript-vue.svg" alt="license">
    </a>
    <a href="https://circleci.com/gh/nativescript-vue/nativescript-vue/tree/master">
       <img src="https://img.shields.io/circleci/project/github/nativescript-vue/nativescript-vue.svg" alt="CircleCI">
    </a>
    <a href="https://codecov.io/gh/nativescript-vue/nativescript-vue">
       <img src="https://img.shields.io/codecov/c/github/nativescript-vue/nativescript-vue.svg" alt="Codecov">
    </a>
</p>

<h2 align="center">Supporting NativeScript-Vue</h2>

NativeScript-Vue is an MIT-licensed open source project made possible by our sponsors:

<!--sponsors-->
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle">
        <a href="https://www.privateinternetaccess.com/?source=nativescript-vue-github" target="_blank">
          <img width="300px" src="https://art.nativescript-vue.org/sponsors/pia.png">
        </a>
      </td>
      <td align="center" valign="middle">
        <a href="https://kiwiirc.com/?source=nativescript-vue-github" target="_blank">
          <img height="50px" src="https://art.nativescript-vue.org/sponsors/kiwiirc.png?v=1">
        </a>
      </td>
      <td align="center" valign="middle">
        <a href="https://www.progress.com/?source=nativescript-vue-github" target="_blank">
          <img height="50px" src="https://art.nativescript-vue.org/sponsors/progress.png">
        </a>
      </td>
    </tr><tr></tr>
  </tbody>
</table>
<!--/sponsors-->

and these awesome backers:

- Tiago Alves
- Kamen Bundev
- Jan Weller
- OpenLitterMap
- Aparajita Fishman
- Hajnalka Molnár Csikós
- Jen Looper
- Packy Tagliaferro
- Alexander Vakrilov
- Dave
- Todd Anglin
- Mohamed Hussain
- Gleb Zhelezin
- Robert M. Svendsen
- Andy Drexler
- ChiwalahSoftware
- Nayir Chami
- Teon Ooi
- Thomas Kuhlmann
- Abdullah Al Mashmoum

If you'd like to join them, please consider [becoming a backer / sponsor on Patreon](https://www.patreon.com/rigor789).

A huge thank you for all of the backers / sponsors!

---

# NativeScript Vue Plugin

This plugin integrates [Vue](https://vuejs.org/) and [NativeScript](https://www.nativescript.org/), allowing you to build cross-platform iOS and Android apps using Vue.

## Contributing

If you feel like contributing to this project, that’s awesome! Start by reading [this repo’s `CONTRIBUTING.MD`](https://github.com/rigor789/nativescript-vue/blob/master/CONTRIBUTING.md) file for details on the required development setup, how to send pull requests, and how to run this repo’s sample app.

If you’d like to get involved with making Vue integration for NativeScript happen, join us in the #vue channel on the [NativeScript community Slack](http://tinyurl.com/nativescriptSlack). 

## License

NativeScript-Vue is licensed under the [MIT license](https://github.com/rigor789/nativescript-vue/blob/master/LICENSE)
